<?php

namespace Drupal\webform_double_opt_in\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Class OptedInEvent.
 *
 * @package Drupal\webform_double_opt_in\Event
 */
class OptedInEvent extends Event {

  /**
   * The Webform ID.
   *
   * @var string
   */
  protected $webformId;

  /**
   * The Webform submission source entity type.
   *
   * @var string|null
   */
  protected $webformSubmissionSourceEntityType;

  /**
   * The Webform submission source entity ID.
   *
   * @var int|string|null
   */
  protected $webformSubmissionSourceEntityId;

  /**
   * The opt-in mail address.
   *
   * @var string
   */
  protected $emailAddress;

  /**
   * OptedInEvent constructor.
   *
   * @param string $webformId
   *   The Webform ID.
   * @param string|null $webformSubmissionSourceEntityType
   *   The Webform submission source entity type.
   * @param int|string|null $webformSubmissionSourceEntityId
   *   The Webform submission source entity ID.
   * @param string $emailAddress
   *   The opt-in mail address.
   */
  public function __construct(
    $webformId,
    $webformSubmissionSourceEntityType,
    $webformSubmissionSourceEntityId,
    $emailAddress
  ) {
    $this->webformId = $webformId;
    $this->webformSubmissionSourceEntityType = $webformSubmissionSourceEntityType;
    $this->webformSubmissionSourceEntityId = $webformSubmissionSourceEntityId;
    $this->emailAddress = $emailAddress;
  }

  /**
   * Returns the Webform ID.
   *
   * @return string
   *   The Webform ID.
   */
  public function getWebformId() {
    return $this->webformId;
  }

  /**
   * Returns the Webform submission source entity type.
   *
   * @return string|null
   *   The type of the submission source entity.
   */
  public function getWebformSubmissionSourceEntityType() {
    return $this->webformSubmissionSourceEntityType;
  }

  /**
   * Returns the Webform submission source entity ID.
   *
   * @return int|string|null
   *   The ID of the submission source entity.
   */
  public function getWebformSubmissionSourceEntityId() {
    return $this->webformSubmissionSourceEntityId;
  }

  /**
   * Returns the opt-in mail address.
   *
   * @return string
   *   The opt-in mail address.
   */
  public function getEmailAddress() {
    return $this->emailAddress;
  }

}
